/*:ts=8*/
/*****************************************************************************
 * FIDOGATE --- Gateway software UNIX Mail/News <-> FIDO NetMail/EchoMail
 *
 * $Id: version.h,v 4.44 2002/12/16 20:23:37 n0ll Exp $
 *
 * Global version number, patch level
 *****************************************************************************/

#define VERSION_MAJOR	4
#define VERSION_MINOR	4
#define PATCHLEVEL	7

#define STATE		"stable"
